@@ -244,32 +244,21 @@ class ContainerReader(object):
             os.remove(temp_name)
 
 
-def extract(filename, dest_dir, deflate=True, recursive=True):
+def extract(filename, folder, deflate=True, recursive=True):
     """
     Распаковка контейнера. Сахар для ContainerReader
 
     :param filename: полное имя файла-контейнера
     :type filename: string
-    :param dest_dir: каталог назначения
-    :type dest_dir: string
+    :param folder: каталог назначения
+    :type folder: string
     :param deflate: паспаковка
     :type deflate: boolean
     :param recursive: рекурсивно достаем все контейнеры
     :type recursive: boolean
     """
-
-    with open(filename, 'rb') as file:
-        ContainerReader(file).extract(dest_dir, deflate, recursive)
-        # from .cv8file import CV8File
-        # from .cv8file16 import CV8File16
-        # if CV8File16.is_v8_file(file):
-        #     CV8File16.parse(file, dest_dir, deflate=True, recursive=True)
-        # if CV8File.is_v8_file(file):
-        #     CV8File.parse(file, dest_dir, deflate=True, recursive=True)
-        # raise Exception('Not v8file')
-
-
-
+    with open(filename, 'rb') as f:
+        ContainerReader(f).extract(folder, deflate, recursive)
 
 
 def decompress_and_extract(src_folder, dest_folder, *, pool=None):
